#!/usr/bin/perl

# enxpool.pl -f <fromaddr> -- <toaddr> [...]

require '/usr/local/spoolerator/spool.pl';

#order of things
# 1.  get sender and recipient(s)
# 2.  get message headers
# 2.1.  get ID for current processing
# 2.2.  get sending IP address
# 3.  write temporary queue file
# 4.  write header file
# 5.  rename temporary queue file to permanent name

# 1.  get sender and recipient(s)
while ($ARGV[0] =~ /^-/) {
  if ($ARGV[0] eq '-f') {
    $from = $ARGV[1];
    shift; shift;
  }
  if ($ARGV[0] eq '--') {
    shift;
    last;
  }
}

@to = @ARGV;
@ARGV=();  #clear out @ARGV

# 2.  get message headers
$headers = "";
while (<>) {
  last if /^$/;
  push(@headers, $_);
}
chomp(@headers);

# 2.0.1.  find the first Received: header for parsing
$recvseen = 0;
foreach $header (@headers) {
  if (!$recvseen) {
    next unless $header =~ /^Received:\s/;
    $recvseen = 1;
    $firstrecv = $header;
  } else {
    last if $header !~ /^\s/;
    $firstrecv .= $header;
  }
}
# 2.1.  get ID for current processing
$firstrecv =~ /SMTP\s+id\s+(\w+)/;
$filename = $1;

# 2.2.  get sending IP address
$firstrecv =~ /\[([^]]+)\]/;
$ip = $1;

# 3.  write temporary queue file
open(QUEFILE, ">$incoming_spool/xf$filename");
print QUEFILE "S$from\n";
foreach (@to) {
  print QUEFILE "R$_\n";
}
print QUEFILE "\$_[$ip]\n";
foreach $header (@headers) {
  print QUEFILE "H$header\n";
}
close(QUEFILE);

# 4.  write header file
open(DATFILE, ">$incoming_spool/df$filename");

while (<>) {
  print DATFILE "$_";
}
close(DATFILE);

# 5.  rename temporary queue file to permanent name
rename("$incoming_spool/xf$filename", "$incoming_spool/qf$filename");
